==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/healthkit/HKCategorySample.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.healthkit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 8.0 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Library("HealthKit") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/HKCategorySample/*</name>*/ 
    extends /*<extends>*/HKSample/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class HKCategorySamplePtr extends Ptr<HKCategorySample, HKCategorySamplePtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(HKCategorySample.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public HKCategorySample() {}
    protected HKCategorySample(SkipInit skipInit) { super(skipInit); }
    /*</constructors>*/
    /*<properties>*/
    @Property(selector = "categoryType")
    public native HKCategoryType getCategoryType();
    @Property(selector = "value")
    public native @MachineSizedSInt long getValue();
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "categorySampleWithType:value:startDate:endDate:metadata:")
    public static native HKCategorySample create(HKCategoryType type, @MachineSizedSInt long value, NSDate startDate, NSDate endDate, HKMetadata metadata);
    @Method(selector = "categorySampleWithType:value:startDate:endDate:")
    public static native HKCategorySample create(HKCategoryType type, @MachineSizedSInt long value, NSDate startDate, NSDate endDate);
    /*</methods>*/
}

==> robovm-cocoatouch-2.3.18-sources.jar: org/robovm/apple/healthkit/HKCategorySample.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.healthkit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*/@Library("HealthKit") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/HKCategorySample/*</name>*/ 
    extends /*<extends>*/HKSample/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class HKCategorySamplePtr extends Ptr<HKCategorySample, HKCategorySamplePtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(HKCategorySample.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    protected HKCategorySample() {}
    protected HKCategorySample(Handle h, long handle) { super(h, handle); }
    protected HKCategorySample(SkipInit skipInit) { super(skipInit); }
    /*</constructors>*/
    /*<properties>*/
    @Property(selector = "categoryType")
    public native HKCategoryType getCategoryType();
    @Property(selector = "value")
    public native @MachineSizedSInt long getValue();
    @Property(selector = "supportsSecureCoding")
    public static native boolean supportsSecureCoding();
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "categorySampleWithType:value:startDate:endDate:metadata:")
    public static native HKCategorySample create(HKCategoryType type, @MachineSizedSInt long value, NSDate startDate, NSDate endDate, HKMetadata metadata);
    @Method(selector = "categorySampleWithType:value:startDate:endDate:")
    public static native HKCategorySample create(HKCategoryType type, @MachineSizedSInt long value, NSDate startDate, NSDate endDate);
    /**
     * @since Available in iOS 9.0 and later.
     */
    @Method(selector = "categorySampleWithType:value:startDate:endDate:device:metadata:")
    public static native HKCategorySample create(HKCategoryType type, @MachineSizedSInt long value, NSDate startDate, NSDate endDate, HKDevice device, HKMetadata metadata);
    /*</methods>*/
}
